@@ -417,13 +417,11 @@ class calc_area:
     
     def __init__(self,
                  df,
-                 delarea:float,
-                 unit_area:str = None
+                 delarea:float = None
                  ):
         
         self.df = df
         self.delarea = delarea
-        self.unit_area = unit_area
         
         if isinstance(self.df, str):
             data = gpd.read_file(self.df)
@@ -435,15 +433,13 @@ class calc_area:
                 data.crs = {'init':'epsg:4326'}
         else:
             raise KeyError(f"{self.df} is errorneous data location, please fix the data location problem")
-        
-        if self.unit_area != None and self.unit_area == 'meter':
-            data['area_m'] = data.geometry.area*(100000**2)
-            ohex = data[data['area_m']>=self.delarea]
-            self.geosolution = ohex
+        if self.delarea == None:
+            data['area_ac'] = data.geometry.area*(100000**2)/4046.86
+            ohex = data[data['area_ac']>=0.0000001]
         else:
             data['area_ac'] = data.geometry.area*(100000**2)/4046.86
             ohex = data[data['area_ac']>=self.delarea]
-            self.geosolution = ohex
+        self.geosolution = ohex
         
         
         
\ No newline at end of file
